BasicOfGameData class abstract
- Implementers
- A5tar7arfElMad
- A5tar7arfElSkoon
- AddBeadNumberLineGame
- AddingWithStrips
- AddingWithTable
- AddRodNumberLineGame
- BasicClickTheSoundGame
- BasicDragOutGame
- BingoArabicGame
- BingoGame
- CalendarGame
- CarGame
- ChartSubType
- CheckWrite
- ChoosecHarfMoshadad
- ChooseClassroomObjects
- ChooseCorrect
- ChooseCorrectWordArabic
- ChooseFamilyMember
- ChooseFavouriteActivity
- ChooseFurniture
- ChooseLamShamseya
- ChooseLightHeavy
- ChooseMagicalEGame
- ChooseMainCharacter
- ChooseOnesTens
- ChoosePaperclips
- ChoosePosition
- ChooseSenses
- ChooseSomePic
- ChooseTheActionPart
- ChooseTheCorrectGame
- ChooseTheCorrectImageOrLetter
- ChooseTheCorrectPart
- ChooseTheCorrectWithSound
- ChooseTheLongestObject
- ChooseTheNamingPart
- ChooseTheNeeded
- ChooseTheRightFeeling
- ChooseTheRightNumber
- ChooseTheSentence2Game
- ChooseTheSentence3Game
- ChooseTheSentenceGame
- ChooseTheShape
- ChooseTheShelter
- ChooseTheSign
- ChooseTheState
- ChooseTheStretchedLetter
- ChooseTheStretchedWord
- ChooseWhatYouCanDo
- ChooseWhichCorrect
- ChooseWithRuler
- ChooseYourAge
- ChooseYourFavoriteAnimal
- ChooseYourFavoriteColor
- ChooseYourFavoriteFood
- ChooseYourGender
- ClickOnTheCardGame
- ClickOnTheFish
- ClickPicture
- ClickPictureOfJob
- ClickPictureOfWord
- ClickPicturePracticalLife
- ClickThePicWithPic
- ClickTheWordGame
- CollectTheFlower
- ColoringShapes
- ColorObjects
- ColorShape
- ColorTheRoots
- ColorTheSeaGame
- ColorTheSVG
- ColorType
- ColorWithWords
- ComparingValues
- CompleteParagraph
- CompleteTheSentenceGame
- CompleteTheStretchedLetter
- CompleteTheTable
- CompleteTheWord
- CountBodyParts
- CountSticksGame
- CountTypeNumber
- CrossOut
- CrossRoadGame
- CTNumberGame
- CTNumberGameWithLine5
- DDTChangeGame
- DescribeTheLeaf
- DiceGame
- Division
- DivisionStamp
- DivisionWithBoard
- DragActivitySequence
- DragAddRodNumberLineGame
- DragAndDropSentence
- DragAndDropWords
- DragBeadsBoard
- DragBodyPartsBoy
- DragBodyPartsGirl
- DragBooks
- DragByColorsGame
- DragClips
- DragClipsType
- DragClothesGame
- DragDayNight
- DragDays
- DragDaySequence
- DragFaceParts
- DragImagesByPosition
- DragIntoGroups
- DragIntoTwoPictures
- DragItems
- DragLabels
- DragNumber
- DragNumberInTable
- DragOneTextByPosition
- DragPicToPicGame
- DragPicToPicWithListeningGame
- DragPicToWordGame
- DragPicWithoutWord
- DragRearrange
- DragRearrangeCulture
- DragRearrangeText
- DragSheets
- DragState
- DragSuitableWord
- DragSun
- DragSunMoon
- DragTextByPosition
- DragTheResult
- DragTheSign
- DragTheSuitableShape
- DragToTheBox
- DragTypeRodNumberLineGame
- DragWhatHappen
- DragWordToPicGame
- DragWorld
- DynamicAdditionWithBeadFrame
- DynamicAdditionWithBeads
- DynamicAdditionWithStamp
- DynamicSubtractionWithBeads
- DynamicSubtractionWithStamp
- E5tarHarfNakes
- E5tarKalmatSa7e7a
- E5tarKelmaAltyBehaShada
- E5tarMo2nes
- E5tarMozker
- Estb3edGame
- FamilyTree
- FixedDragGame
- FollowTheDirection
- FurnitureDragAndDrop
- HearAndChoose
- LabelRooms
- ListenAndChooseGame
- ListenAndChooseWithSound
- ListenAndTick
- ListenChooseYourFavorite
- ListenClickToChoose
- ListenClickToChooseWithListenTap
- ListenColor
- ListenDragAndDrop
- ListenToStory
- MatchFractions
- MatchGame
- MatchingArabic
- MatchMagicE
- MatchRooms
- MatchSenses
- MatchUpGame
- MatchUpGameMath
- MatchVertical
- MatchVerticalLamShamseya
- MatchWordToPic
- MathChooseBeadsAddLine
- MathChooseBeadsOE
- MathChooseBlocksAdd
- MathChooseBlocksAddLine
- MathChooseBlocksSub
- MathChooseBoard
- MathChooseNumberSticksOrBeadsOrBlocks
- MathChooseOEDomino
- MathChooseSticksOrBeadsOrBlocks
- MathDragBlocksAdd
- MathDragBlocksSub
- MathDragDominoOE
- MathDragSticks
- MathSortingBeads
- MathSortingSticksOrBeadsOrBlocks
- MazeByOrderGame
- MazeGame
- MemoryCard
- MonthsOfTheYear
- MultipleChoices
- MultipleTyping
- MultiplicationBoard
- Multiplying
- MultiplyingStamp
- NumberOfBlocks
- NumbersOnMap
- OrderNumbersGame
- PuzzleGame
- RearrangeGame
- ScaleGame
- ShareTheCake
- SkipCounting
- SnakeGameAdd
- SnakeSubtraction
- SortGender
- SortingActivityGame
- SortingArabicText
- SortingCupsGame
- SortingCupsGameAv
- sortingGroupsGame
- SortingMath
- SortingNumbersGame
- SortingPicMath
- SortingPicturesGame
- SortingSensesGame
- SpellingGame
- SpellingWordGame
- SplitThePictures
- StarGame
- StaticAdditionWithBeads
- StaticAdditionWithStamps
- StaticSubtractionWithBeads
- StaticSubtractionWithStamp
- SubRodsChooseNumberGame
- SubRodsTypeNumberGame
- SubWithStrips
- SubWithTable
- TextChooseTheCorrect
- TickMultipleChoices
- TickTheCorrect
- TickTheCorrectAnswer
- TickTheLonger
- TickThePic
- TickThePicMath
- TickThePicWithoutSaying
- TickTheRightMath
- TickWithSentence
- TraceShapes
- TraceWords
- Tracking
- TrainingChooseTheStretchedLetter
- TreasureMap
- TupeWithRuler
- TypeOnesTens
- TypeTheMissingNumber
- TypeTheNumber
- TypeTheNumberInChain
- TypeTheNumberInChainNotGuided
- TypingCounting
- Video
- WordFamilyGame
- WriteTheSides
- WriteValues
- XOutGame
- XOutMath
- XOutMath2
- XOutPracticalLife
- XOutWithImage
- XOutWithPicture
Constructors
Properties
- changeTheLogicOfUi ↔ bool
-
getter/setter pair
- countOfTries ↔ int
-
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- isConnect ↔ bool
-
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- titleImageAr ↔ String?
-
getter/setter pair
- titleImageEn ↔ String
-
getter/setter pair
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Properties
-
enumValues
↔ List<
String> -
getter/setter pair