TalkTts class

Constructors

TalkTts()
factory

Properties

data StateOfTalk
getter/setter pair
flutterTts ↔ FlutterTts
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
wordPlayer ↔ AudioPlayer
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
reBackTheDefaultValue() → dynamic
reStopTheDefaultValue() → dynamic
startTalk({required TTSModel dataParam}) Future
stopTalk() → dynamic
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

mainEnginUse String
getter/setter pair